"use strict";

function ScrollingBackground(url, canvasWidth, canvasHeight) {

  this.canvasWidth = canvasWidth;
  this.canvasHeight = canvasHeight;
  
  this.image = new Image();
  this.image.src = url;

  this.x = 0;
  this.y = 0;

  this.autoscrollX = 0;
  this.autoscrollY = 0;

  var self = this;
  this.image.onload = function() { self.loaded = true; self.init(); };
}

ScrollingBackground.prototype.init = function() {

  this.backgroundWidth = this.image.width;
  this.backgroundHeight = this.image.height;

};

ScrollingBackground.prototype.scroll = function(dx, dy) {
  this.x = (this.x + dx) % this.backgroundWidth;
  this.y = (this.y + dy) % this.backgroundHeight;
};

ScrollingBackground.prototype.autoscroll = function(dx, dy) {
  this.autoscrollX -= dx;
  this.autoscrollY -= dy;
};

ScrollingBackground.prototype.update = function(dt) {
  this.scroll(this.autoscrollX, this.autoscrollY);
  
};

ScrollingBackground.prototype.render = function(context, dt) {
  var y = this.y > 0 ? this.y - this.backgroundHeight : this.y;
  while(y < this.canvasHeight ) {
    var x = this.x > 0 ? this.x - this.backgroundWidth : this.x;
    while(x < this.canvasWidth) {
      context.drawImage(this.image, x, y, this.backgroundWidth, this.backgroundHeight);
      x += this.backgroundWidth;
    }
    y += this.backgroundHeight;
  }
};
