"use strict";
/**
 * Animated sprite
 * @param {string} url         Url of the image containing sprite frames
 * @param {int} frameWidth  width of individual frame
 * @param {int} frameHeight height of individual frame
 * @param {int} frameSpaceX horizontal margin between frames
 * @param {int} frameSpaceY vertical margin between frames
 * @param {int} frameCountX frame count per row
 * @param {int} frameCountY frame count per col
 */
function AnimatedSprite(url, frameWidth, frameHeight, frameSpaceX, frameSpaceY, frameCountX, frameCountY) {
  this.loaded = false;
  this.frameWidth = frameWidth;
  this.frameHeight = frameHeight;
  this.frameCountX = frameCountX;
  this.frameCountY = frameCountY;
  this.frameSpaceX = frameSpaceX;
  this.frameSpaceY = frameSpaceY;

  this.image = new Image();
  this.image.src = url;

  this.frameCount = this.frameCountX * this.frameCountY;
  this.frameIndex = 0;
  this.frameX = 0;
  this.frameY = 0;

  this.x = 0;
  this.y = 0;

  var self = this;
  this.image.onload = function() { self.loaded = true; };

}

/**
 * Reset animation
 */
AnimatedSprite.prototype.reset = function() {
  this.frameIndex = 0;
  this.frameX = 0;
  this.frameY = 0;
};

/**
 * Update animation by cycling between frames
 * @param  {int} dt elapsed time
 */
AnimatedSprite.prototype.update = function(dt) {
  this.frameIndex = (this.frameIndex + 1) % this.frameCount;   
  this.frameX = (this.frameWidth + this.frameSpaceX) * (this.frameIndex % this.frameCountX);
  this.frameY = (this.frameHeight + this.frameSpaceY) * ~~(this.frameIndex / this.frameCountX);
};

/**
 * Render sprite
 * @param {2DContext} context 
 * @param {int} dt elapsed time
 */
AnimatedSprite.prototype.render = function(context, dt) {
  context.drawImage(this.image, 
    this.frameX, this.frameY, this.frameWidth, this.frameHeight,
    this.x, this.y, this.frameWidth, this.frameHeight);
};


/**
 * Set position of the sprite on the canvas
 * @param {int} x
 * @param {int} y
 */
AnimatedSprite.prototype.setPosition = function(x, y) {
  this.x = x;
  this.y = y;
};


/**
 * Move the sprite by the specified direction
 * @param  {int} x 
 * @param  {int} y 
 */
AnimatedSprite.prototype.move = function(x, y) {
  this.x += x;
  this.y += y;
};

